Documentation
¶
Index ¶
- func Bool(f *frm.Field, inp ...string)
- func DateTime(f *frm.Field, inp ...string)
- func FileReq(f *frm.Field, inp ...string)
- func Float32(f *frm.Field, inp ...string)
- func Float64(f *frm.Field, inp ...string)
- func IsValid(urlValues url.Values, fields []frm.Field) ([]frm.Field, bool)
- func IsValidRequest(r *http.Request, fields []frm.Field) ([]frm.Field, bool)
- func Regex(f *frm.Field, inp ...string)
- func RegexReq(f *frm.Field, inp ...string)
- func Str(f *frm.Field, inp ...string)
- func StrOpt(f *frm.Field, inp ...string)
- func StrReq(f *frm.Field, inp ...string)
- func Uint(f *frm.Field, inp ...string)
- func Uint8(f *frm.Field, inp ...string)
- func Uint8List(f *frm.Field, inp ...string)
- func Uint8Opt(f *frm.Field, inp ...string)
- func Uint8Req(f *frm.Field, inp ...string)
- func Uint16(f *frm.Field, inp ...string)
- func Uint16List(f *frm.Field, inp ...string)
- func Uint16Opt(f *frm.Field, inp ...string)
- func Uint16Req(f *frm.Field, inp ...string)
- func Uint32(f *frm.Field, inp ...string)
- func Uint32List(f *frm.Field, inp ...string)
- func Uint32Opt(f *frm.Field, inp ...string)
- func Uint32Req(f *frm.Field, inp ...string)
- func Uint64(f *frm.Field, inp ...string)
- func Uint64List(f *frm.Field, inp ...string)
- func Uint64Opt(f *frm.Field, inp ...string)
- func Uint64Req(f *frm.Field, inp ...string)
- func UintList(f *frm.Field, inp ...string)
- func UintOpt(f *frm.Field, inp ...string)
- func UintReq(f *frm.Field, inp ...string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsValidRequest ¶
IsValidRequest gathers the form submitted from GET and POST requests and then calls IsValid().
func StrOpt ¶
StrOpt validates inp as a string array. Check value matches one of the options (optional).
func Uint16List ¶
Uint16List validates inp as a slice of unsigned 16-bit integers.
func Uint32List ¶
Uint32List validates inp as a slice of unsigned 32-bit integers.
func Uint64List ¶
Uint64List validates inp as a slice of unsigned 64-bit integers.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.